@@ -1,20 +1,14 @@
 """A collapsible widget to hide and unhide child widgets"""
 from typing import Optional
 
-from qtpy.QtCore import (
-    QAbstractAnimation,
-    QEasingCurve,
-    QMargins,
-    QPropertyAnimation,
-    Qt,
-)
+from qtpy.QtCore import QEasingCurve, QEvent, QMargins, QObject, QPropertyAnimation, Qt
 from qtpy.QtWidgets import QFrame, QPushButton, QVBoxLayout, QWidget
 
 
 class QCollapsible(QFrame):
     """A collapsible widget to hide and unhide child widgets.
 
-    Based on https://stackoverflow.com/a/68141638
+    Based on [https://stackoverflow.com/a/68141638](https://stackoverflow.com/a/68141638)
     """
 
     _EXPANDED = "▼  "
@@ -23,10 +17,11 @@ class QCollapsible(QFrame):
     def __init__(self, title: str = "", parent: Optional[QWidget] = None):
         super().__init__(parent)
         self._locked = False
+        self._is_animating = False
 
         self._toggle_btn = QPushButton(self._COLLAPSED + title)
         self._toggle_btn.setCheckable(True)
-        self._toggle_btn.setStyleSheet("text-align: left; background: transparent;")
+        self._toggle_btn.setStyleSheet("text-align: left; border: none; outline: none;")
         self._toggle_btn.toggled.connect(self._toggle)
 
         # frame layout
@@ -38,6 +33,7 @@ class QCollapsible(QFrame):
         self._animation = QPropertyAnimation(self)
         self._animation.setPropertyName(b"maximumHeight")
         self._animation.setStartValue(0)
+        self._animation.finished.connect(self._on_animation_done)
         self.setDuration(300)
         self.setEasingCurve(QEasingCurve.Type.InOutCubic)
 
@@ -77,19 +73,21 @@ class QCollapsible(QFrame):
 
     def addWidget(self, widget: QWidget):
         """Add a widget to the central content widget's layout."""
+        widget.installEventFilter(self)
         self._content.layout().addWidget(widget)
 
     def removeWidget(self, widget: QWidget):
         """Remove widget from the central content widget's layout."""
         self._content.layout().removeWidget(widget)
+        widget.removeEventFilter(self)
 
     def expand(self, animate: bool = True):
         """Expand (show) the collapsible section"""
-        self._expand_collapse(QAbstractAnimation.Direction.Forward, animate)
+        self._expand_collapse(QPropertyAnimation.Direction.Forward, animate)
 
     def collapse(self, animate: bool = True):
         """Collapse (hide) the collapsible section"""
-        self._expand_collapse(QAbstractAnimation.Direction.Backward, animate)
+        self._expand_collapse(QPropertyAnimation.Direction.Backward, animate)
 
     def isExpanded(self) -> bool:
         """Return whether the collapsible section is visible"""
@@ -105,12 +103,12 @@ class QCollapsible(QFrame):
         return self._locked
 
     def _expand_collapse(
-        self, direction: QAbstractAnimation.Direction, animate: bool = True
+        self, direction: QPropertyAnimation.Direction, animate: bool = True
     ):
         if self._locked:
             return
 
-        forward = direction == QAbstractAnimation.Direction.Forward
+        forward = direction == QPropertyAnimation.Direction.Forward
         text = self._EXPANDED if forward else self._COLLAPSED
 
         self._toggle_btn.setChecked(forward)
@@ -120,9 +118,23 @@ class QCollapsible(QFrame):
         if animate:
             self._animation.setDirection(direction)
             self._animation.setEndValue(_content_height)
+            self._is_animating = True
             self._animation.start()
         else:
             self._content.setMaximumHeight(_content_height if forward else 0)
 
     def _toggle(self):
         self.expand() if self.isExpanded() else self.collapse()
+
+    def eventFilter(self, a0: QObject, a1: QEvent) -> bool:
+        """If a child widget resizes, we need to update our expanded height."""
+        if (
+            a1.type() == QEvent.Type.Resize
+            and self.isExpanded()
+            and not self._is_animating
+        ):
+            self._expand_collapse(QPropertyAnimation.Direction.Forward, animate=False)
+        return False
+
+    def _on_animation_done(self):
+        self._is_animating = False
